﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using Unitilities;

public class Bullet : MonoBehaviour {

	public float timeToVanish = 5f;

	private float _vanishTimer;
	private bool _bVanished = false;

	private Movement _movementScript;
	private SpriteRenderer _spriteRenderer;

	private bool _bUsePooling = false;

	void Awake() {
		_movementScript = GetComponent<Movement>();
		_spriteRenderer = GetComponentInChildren<SpriteRenderer>();
	}

	public void Shoot(Facing facing, float speed, bool bUsePool) {
		_bUsePooling = bUsePool;
		_vanishTimer = timeToVanish;
		_bVanished = false;

		_movementScript.currentMovement = facing == Facing.Left ? Vector2.left * speed : Vector2.right * speed;

		_spriteRenderer.flipX = facing == Facing.Left;
	}
	
	// Update is called once per frame
	void Update () {
		if (_bVanished) {
			return;
		}

		_vanishTimer -= Time.deltaTime;

		if (_vanishTimer < 0f) {
			_bVanished = true;

			if (_bUsePooling) {
				GameObjectPool.Put(gameObject);
			} else {
				Destroy(gameObject);
			}
		}
	}
}
